<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use DB;
use Session;
use Storage;
use Carbon\Carbon;
use Auth;

use App\Page;

class PageController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    function __construct()
    {
         $this->middleware('permission:page-list|page-create|page-edit|page-delete', ['only' => ['index','store']]);
         $this->middleware('permission:page-create', ['only' => ['create','store']]);
         $this->middleware('permission:page-edit', ['only' => ['edit','update']]);
         $this->middleware('permission:page-delete', ['only' => ['destroy']]);

        // TinyMCE
        $tm[0]['selector'] = 'excerpt';
        $tm[0]['upload_url'] = 'pages';
        $tm[0]['field_height'] = '300';

        $tm[1]['selector'] = 'body';
        $tm[1]['upload_url'] = 'pages';
        $tm[1]['field_height'] = '600';

        $this->tm = $tm;

        // Upload folder
        $this->folder = 'pages';
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        // page header
        $title = __('dashboard.title_pages');
        $route = route('pages.create');
        $pageType = 'index';
        $canCreate = 'page-create';
        $canExport = null;

        $pages = Page::pagesAll();

        return view('pages.index',compact('title','route','pageType','canCreate','canExport',
                                                        'pages'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        // page header
        $title = __('dashboard.title_pages');
        $route = route('pages.index');
        $pageType = 'create';

        $tm = $this->tm;

        return view('pages.create',compact('title','route','pageType','tm'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $loggedIn = Auth::user();

        $this->validate($request, [
            'title' => 'required',
            'slug' => 'required|unique:pages,slug'
        ]);
    
        $page = Page::create([
            'author_id' => $loggedIn->id,
            'title' => $request->input('title'),
            'slug' => $request->input('slug'),
            'excerpt' => $request->input('excerpt'),
            'body' => $request->input('body'),
            'status' => $request->input('status'),
            'meta_description' => $request->input('meta_description'),
            'meta_keywords' => $request->input('meta_keywords')
        ]);

        // IMG upload
        if (null !== request('page_image')):

            $file = $request->file('page_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$page->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);

            $page = Page::where('id',$page->id)
                                    ->update([
                                        'page_image' => $imgNAME
                                    ]);
        endif;
    
        return redirect()->route('pages.index')
                        ->with('success','Page created successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        // page header
        $title = __('dashboard.title_pages');
        $route = route('pages.index');
        $pageType = 'show';

        $page = Page::pagesByID($id);
    
        return view('pages.show',compact('title','route','pageType',
                                                'page'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        // page header
        $title = __('dashboard.title_pages');
        $route = route('pages.index');
        $pageType = 'edit';

        // TinyMCE
        $tm = $this->tm;

        $page = Page::pagesByID($id);
    
        return view('pages.edit',compact('title','route','pageType','tm',
                                                        'page'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {   

        $loggedIn = Auth::user();


        $this->validate($request, [
            'title' => 'required',
            'slug' => 'required'
        ]);
    
        $page = Page::find($id);
        $page->author_id = $loggedIn->id;
        $page->title = $request->input('title');
        $page->slug = $request->input('slug');
        $page->excerpt = $request->input('excerpt');
        $page->body = $request->input('body');
        $page->status = $request->input('status');
        $page->meta_description = $request->input('meta_description');
        $page->meta_keywords = $request->input('meta_keywords');
        

        // IMG upload
        if (null !== request('page_image')):

            $file = $request->file('page_image');

            $imgNAME = date_format(Carbon::now(),"dmYHis").'-'.$page->id.'-'.$file->getClientOriginalName();


            $path = url('storage/'.$this->folder.'/').'/'.$imgNAME;
            $imgpath = $file->move(storage_path('app/public/'.$this->folder.'/'),$imgNAME);
           
            $page->page_image = $imgNAME;
        endif;

        $page->save();
    
        return redirect()->route('pages.index')
                        ->with('success','Page updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        DB::table("pages")->where('id',$id)->delete();

        return redirect()->route('pages.index')
                        ->with('success','Page deleted successfully');
    }
}
